from PyObjCTools.TestSupport import TestCase, arch_only, min_os_level

import Virtualization


class TestVZMacHardwareModel(TestCase):
    @min_os_level("12.0")
    @arch_only("arm64")
    def test_methods(self):
        self.assertResultIsBOOL(Virtualization.VZMacHardwareModel.isSupported)



from PyObjCTools.TestSupport import TestCase, min_os_level

import Virtualization


class TestVZVirtioBlockDeviceConfiguration(TestCase):
    @min_os_level("12.3")
    def test_methods12_3(self):
        self.assertResultIsBOOL(
            Virtualization.VZVirtioBlockDeviceConfiguration.validateBlockDeviceIdentifier_error_,
        )
        self.assertArgIsOut(
            Virtualization.VZVirtioBlockDeviceConfiguration.validateBlockDeviceIdentifier_error_,
            1,
        )



from PyObjCTools.TestSupport import TestCase, min_os_level

import Virtualization


class TestVZVirtioFileSystemDeviceConfiguration(TestCase):
    @min_os_level("12.0")
    def test_methods(self):
        self.assertResultIsBOOL(
            Virtualization.VZVirtioFileSystemDeviceConfiguration.validateTag_error_
        )
        self.assertArgIsOut(
            Virtualization.VZVirtioFileSystemDeviceConfiguration.validateTag_error_, 1
        )



from PyObjCTools.TestSupport import TestCase, min_os_level, arch_only

import Virtualization


class TestVZMacAuxiliaryStorage(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Virtualization.VZMacAuxiliaryStorageInitializationOptions)

    def test_constants(self):
        self.assertEqual(
            Virtualization.VZMacAuxiliaryStorageInitializationOptionAllowOverwrite,
            1 << 0,
        )

    @min_os_level("12.0")
    @arch_only("arm64")
    def testMethods12_0(self):
        self.assertArgIsOut(
            Virtualization.VZMacAuxiliaryStorage.initCreatingStorageAtURL_hardwareModel_options_error_,
            3,
        )



from PyObjCTools.TestSupport import TestCase, min_os_level

import Virtualization


class TestVZDiskImageStorageDeviceAttachment(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Virtualization.VZDiskImageCachingMode)
        self.assertIsEnumType(Virtualization.VZDiskImageSynchronizationMode)

    def test_constants(self):
        self.assertEqual(Virtualization.VZDiskImageSynchronizationModeFull, 1)
        self.assertEqual(Virtualization.VZDiskImageSynchronizationModeFsync, 2)
        self.assertEqual(Virtualization.VZDiskImageSynchronizationModeNone, 3)

        self.assertEqual(Virtualization.VZDiskImageCachingModeAutomatic, 0)
        self.assertEqual(Virtualization.VZDiskImageCachingModeUncached, 1)
        self.assertEqual(Virtualization.VZDiskImageCachingModeCached, 2)

    def test_methods(self):
        self.assertArgIsBOOL(
            Virtualization.VZDiskImageStorageDeviceAttachment.initWithURL_readOnly_error_,
            1,
        )
        self.assertArgIsOut(
            Virtualization.VZDiskImageStorageDeviceAttachment.initWithURL_readOnly_error_,
            2,
        )
        self.assertResultIsBOOL(
            Virtualization.VZDiskImageStorageDeviceAttachment.isReadOnly
        )

    @min_os_level("12.0")
    def test_methods12_0(self):
        self.assertArgIsBOOL(
            Virtualization.VZDiskImageStorageDeviceAttachment.initWithURL_readOnly_cachingMode_synchronizationMode_error_,
            1,
        )
        self.assertArgIsOut(
            Virtualization.VZDiskImageStorageDeviceAttachment.initWithURL_readOnly_cachingMode_synchronizationMode_error_,
            4,
        )



from PyObjCTools.TestSupport import TestCase, min_os_level

import Virtualization


class TestVZSharedDirectory(TestCase):
    @min_os_level("12.0")
    def test_methods(self):
        self.assertArgIsBOOL(Virtualization.VZSharedDirectory.initWithURL_readOnly_, 1)
        self.assertResultIsBOOL(Virtualization.VZSharedDirectory.isReadOnly)



from PyObjCTools.TestSupport import TestCase, min_os_level, arch_only

import Virtualization


class TestVZMacOSInstaller(TestCase):
    @min_os_level("12.0")
    @arch_only("arm64")
    def test_methods(self):
        self.assertArgIsBlock(
            Virtualization.VZMacOSInstaller.installWithCompletionHandler_, 0, b"v@"
        )



from PyObjCTools.TestSupport import TestCase, min_os_level, arch_only

import Virtualization


class TestVZMacOSRestoreImage(TestCase):
    @min_os_level("12.0")
    @arch_only("arm64")
    def test_methods(self):
        self.assertArgIsBlock(
            Virtualization.VZMacOSRestoreImage.loadFileURL_completionHandler_,
            1,
            b"v@@",
        )
        self.assertArgIsBlock(
            Virtualization.VZMacOSRestoreImage.fetchLatestSupportedWithCompletionHandler_,
            0,
            b"v@@",
        )



from PyObjCTools.TestSupport import TestCase, min_os_level

import Virtualization


class TestVZVirtualMachineView(TestCase):
    @min_os_level("12.0")
    def test_methods(self):
        self.assertResultIsBOOL(
            Virtualization.VZVirtualMachineView.capturesSystemKeys,
        )
        self.assertArgIsBOOL(
            Virtualization.VZVirtualMachineView.setCapturesSystemKeys_,
            0,
        )
